;
;+
;   Name: setssw_windows
;
;   Purpose: Emulate script SETSSW for window
;		Executes any _paths or _env files, then creates path.
;
;   Input Parameters:
;		required instruments selected by keyword....
;   Calling Examples:
;
;		setssw_windows,/trace,/sxt
;
;   Calls:
;		set_logenv, ssw_path
;   Keyword Parameters:
;   Restrictions:
;       WINDOWS only
;   History:
;        1-Jun-1999 (RDB) - Created
;        3-Jun-1999 (SLF) - renamed setssw.pro->setssw_windows.pro
;       18-Mar-2000 (RDB) - removed some "help" printouts
;       29-Mar-2000 (RDB) - do site after instrument at instrument level
;-

pro setssw_windows,_extra=_extra

common ssw_setup_common

SSW = get_logenv('$SSW')
instr_list_flag = intarr(n_elements(instr_list))


;	examine the keywords and see what was selected
instr=''
if n_elements(_extra) eq 1 then $
   instr=tag_names(_extra)
;help,instr
;print,instr
for j = 0,n_elements(instr)-1 do begin
   wq = where(strpos(strupcase(instr_list),instr(j)) ge 0)
   if wq(0) ge 0 then instr_list_flag(wq(0)) = 1
endfor

;	following were selected...
print,'* Following instruments selected:'
print,instr_list(where(instr_list_flag gt 0))
;print,instr_list_flag


qq = strarr(2,n_elements(instr_list))
for j=0,n_elements(instr_list)-1 do qq(*,j)=str_sep(instr_list(j),'/')
;help,qq

qq = qq(*,where(instr_list_flag gt 0))
;help,qq

;	execute the site path definition
file = findfile(SSW+'\site\setup\setup.ssw_paths')
if file(0) ne '' then set_logenv,file=file

;	define env. variables at mission level
print,'* Mission level setup files'
missions = qq(0,uniq(qq(0,*)))
for j=0,n_elements(missions)-1 do begin
;		generic setup...
;	do setup.xxxx_paths then setup.xxxx_env
   wwx = SSW+'\gen\setup\setup.'+missions(j)
   file = findfile(wwx+'_paths')
   if file(0) ne '' then set_logenv,file=file
   file = findfile(wwx+'_env')
   if file(0) ne '' then set_logenv,file=file
;		site specific setup
;	do setup.xxxx_paths then setup.xxxx_env
   wwx = SSW+'\site\setup\setup.'+missions(j)
   file = findfile(wwx+'_paths')
   if file(0) ne '' then set_logenv,file=file
   file = findfile(wwx+'_env')
   if file(0) ne '' then set_logenv,file=file
endfor

;	now define those set at the instrument level
;	do setup.xxxx_paths then setup.xxxx_env
print,'* Instrument level setup files'
for j=0,n_elements(qq)/2-1 do begin
   mission_set = arr2str(qq(*,j),'/')
   if qq(0,j) eq qq(1,j) then mission_set = qq(1,j)   ;e.g. trace/trace
;
   wwx = SSW+'/'+mission_set+'/setup/setup.'+qq(1,j)
   file = findfile(wwx+'_paths')
   if file(0) ne '' then set_logenv,file=file
   file = findfile(wwx+'_env')
   if file(0) ne '' then set_logenv,file=file
;  	do site version of the instrument file
   wwx = SSW+'\site\setup\setup.'+qq(1,j)
;   print,wwx
   file = findfile(wwx+'_env')
   if file(0) ne '' then set_logenv,file=file

endfor


;	Set path to include whatever instruments were set by keywords
;	Note: $SSW_xxxx (where xxxx is an instrument) must have been set
;	before this can be done. If the standard location define by $SSW_xxxx
;	needs to be changed, this should be done in the setup.xxxx_env file in
;	directory $SSW/site/setup (e.g to change HESSI to released version).
;
ssw_path,_extra=_extra

end
